@@ -3,38 +3,37 @@ BEGIN {
   $B::Hooks::EndOfScope::AUTHORITY = 'cpan:FLORA';
 }
 {
-  $B::Hooks::EndOfScope::VERSION = '0.09_02';
+  $B::Hooks::EndOfScope::VERSION = '0.11_01';
 }
 # ABSTRACT: Execute code after a scope finished compilation
 
 use strict;
 use warnings;
 
-# note - the tie() fallback will probably work on 5.6 as well,
+# note - a %^H tie() fallback will probably work on 5.6 as well,
 # if you need to go that low - sane patches passing *all* tests
 # will be gladly accepted
 use 5.008001;
 
-use Module::Implementation;
+my $exp_ose;
+BEGIN {
+  require Module::Implementation;
+  my $impl = Module::Implementation::implementation_for('B::Hooks::EndOfScope') || do {
+    Module::Implementation::build_loader_sub(
+      implementations => [ 'XS',  'PP' ],
+      symbols => [ 'on_scope_end' ],
+    )->();
+    Module::Implementation::implementation_for('B::Hooks::EndOfScope');
+  };
 
-use Sub::Exporter -setup => {
-  exports => [on_scope_end => sub {
+  *on_scope_end = $impl eq 'XS'
+    ? \&B::Hooks::EndOfScope::XS::on_scope_end
+    : \&B::Hooks::EndOfScope::PP::on_scope_end
+  ;
+}
 
-    my $impl = Module::Implementation::implementation_for('B::Hooks::EndOfScope') || do {
-      Module::Implementation::build_loader_sub(
-        implementations => [ 'XS',  'PP' ],
-        symbols => [ 'on_scope_end' ],
-      )->();
-      Module::Implementation::implementation_for('B::Hooks::EndOfScope');
-    };
-
-    if ($impl eq 'XS') {
-      \&B::Hooks::EndOfScope::XS::on_scope_end;
-    }
-    else {
-      \&B::Hooks::EndOfScope::PP::on_scope_end;
-    }
-  }],
+use Sub::Exporter::Progressive -setup => {
+  exports => [ 'on_scope_end' ],
   groups  => { default => ['on_scope_end'] },
 };
 
@@ -42,6 +41,7 @@ use Sub::Exporter -setup => {
 1;
 
 __END__
+
 =pod
 
 =encoding utf-8
@@ -74,12 +74,12 @@ This is exported by default. See L<Sub::Exporter> on how to customize it.
 
 =head1 PURE-PERL MODE CAVEAT
 
-Handling exceptions in scope-end callbacks is tricky business. While
-L<Variable::Magic> has access to some very dark sorcery to make it possible to
-throw an exception from within a callback, the pure-perl implementation does
-not have access to these hacks. Therefore, what would have been a compile-time
-exception is instead converted to a warning, and your execution will continue
-as if the exception never happened.
+While L<Variable::Magic> has access to some very dark sorcery to make it
+possible to throw an exception from within a callback, the pure-perl
+implementation does not have access to these hacks. Therefore, what
+would have been a compile-time exception is instead converted to a
+warning, and your execution will continue as if the exception never
+happened.
 
 To explicitly request an XS (or PP) implementation one has two choices. Either
 to import from the desired implementation explicitly:
@@ -119,4 +119,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
