@@ -3,7 +3,7 @@ BEGIN {
   $B::Hooks::EndOfScope::PP::AUTHORITY = 'cpan:FLORA';
 }
 {
-  $B::Hooks::EndOfScope::PP::VERSION = '0.09_02';
+  $B::Hooks::EndOfScope::PP::VERSION = '0.11_01';
 }
 # ABSTRACT: Execute code after a scope finished compilation - PP implementation
 
@@ -16,7 +16,7 @@ use constant _PERL_VERSION => "$]";
 BEGIN {
   if (_PERL_VERSION =~ /^5\.009/) {
     # CBA to figure out where %^H got broken and which H::U::HH is sane enough
-    die "B::Hooks::EndOfScope does not operate on perl 5.9.X in pure-perl mode by design\n"
+    die "By design B::Hooks::EndOfScope does not operate in pure-perl mode on perl 5.9.X\n"
   }
   elsif (_PERL_VERSION < '5.010') {
     require_module('B::Hooks::EndOfScope::PP::HintHash');
@@ -28,7 +28,7 @@ BEGIN {
   }
 }
 
-use Sub::Exporter -setup => {
+use Sub::Exporter::Progressive -setup => {
   exports => ['on_scope_end'],
   groups  => { default => ['on_scope_end'] },
 };
@@ -48,8 +48,6 @@ sub __invoke_callback {
     ) . "\n\n$err\n\r" );
 
     sleep 1 if -t *STDERR;  # maybe a bad idea...?
-
-    $@ = $err;  # not that it matters much
   };
 }
 
@@ -57,6 +55,7 @@ sub __invoke_callback {
 1;
 
 __END__
+
 =pod
 
 =encoding utf-8
@@ -108,4 +107,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
