@@ -46,6 +46,7 @@ sub on_scope_end (&) {
 1;
 
 __END__
+
 =pod
 
 =encoding utf-8
@@ -54,10 +55,20 @@ __END__
 
 B::Hooks::EndOfScope::PP::FieldHash
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Florian Ragwitz <rafl@debian.org>
 
+=item *
+
+Peter Rabbitson <ribasushi@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2012 by Florian Ragwitz.
@@ -66,4 +77,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
