@@ -1,5 +1,6 @@
 # Implementtion of a pure-perl on_scope_end for perl 5.8.X
-# (relies on Hash::Util:FieldHash)
+# (relies on lack of compile/runtime duality of %^H before 5.10
+# which makes guard object operation possible)
 
 package # hide from the pauses
   B::Hooks::EndOfScope::PP::HintHash;
@@ -12,25 +13,26 @@ use warnings;
 sub on_scope_end (&) {
   $^H |= 0x020000;
 
-  push @{
-    $^H{'__B_H_EOS__guardstack__'}
-      ||= bless ([], 'B::Hooks::EndOfScope::PP::_SG_STACK')
-  }, shift;
+  # do not bless the coderef directly - DESTROY on crefs is wonky
+  # on some perl versions
+  my $g = [ shift ];
+  $^H{ ref $g } = bless $g, 'B::Hooks::EndOfScope::PP::_ActionGuard';
 }
 
 package # hide from the pauses
-  B::Hooks::EndOfScope::PP::_SG_STACK;
+  B::Hooks::EndOfScope::PP::_ActionGuard;
 
 use warnings;
 use strict;
 
 sub DESTROY {
-  B::Hooks::EndOfScope::PP::__invoke_callback($_) for @{$_[0]};
+  B::Hooks::EndOfScope::PP::__invoke_callback($_[0][0]);
 }
 
 1;
 
 __END__
+
 =pod
 
 =encoding utf-8
@@ -61,4 +63,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
