@@ -3,7 +3,7 @@ BEGIN {
   $B::Hooks::EndOfScope::XS::AUTHORITY = 'cpan:FLORA';
 }
 {
-  $B::Hooks::EndOfScope::XS::VERSION = '0.09_02';
+  $B::Hooks::EndOfScope::XS::VERSION = '0.11_01';
 }
 # ABSTRACT: Execute code after a scope finished compilation - XS implementation
 
@@ -13,17 +13,24 @@ use warnings;
 BEGIN {
   require Module::Runtime;
   # Adjust the Makefile.PL if changing this minimum version
-  Module::Runtime::use_module('Variable::Magic', '0.34');
+  Module::Runtime::use_module('Variable::Magic', '0.48');
 }
 
-use Sub::Exporter -setup => {
+use Sub::Exporter::Progressive -setup => {
   exports => ['on_scope_end'],
   groups  => { default => ['on_scope_end'] },
 };
 
 my $wiz = Variable::Magic::wizard
   data => sub { [$_[1]] },
-  free => sub { $_->() for @{ $_[1] }; () }
+  free => sub { $_->() for @{ $_[1] }; () },
+  # When someone localise %^H, our magic doesn't want to be copied
+  # down. We want it to be around only for the scope we've initially
+  # attached ourselfs to. Merely having MGf_LOCAL and a noop svt_local
+  # callback achieves this. If anything wants to attach more magic of our
+  # kind to a localised %^H, things will continue to just work as we'll be
+  # attached with a new and empty callback list.
+  local => \undef
 ;
 
 sub on_scope_end (&) {
@@ -40,9 +47,11 @@ sub on_scope_end (&) {
 }
 
 
+
 1;
 
 __END__
+
 =pod
 
 =encoding utf-8
@@ -92,4 +101,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
